======
GDB-ML
======


.. image:: https://img.shields.io/pypi/v/gdb_ml.svg
        :target: https://pypi.python.org/pypi/gdb_ml

.. image:: https://img.shields.io/travis/Ye-Buehler/gdb_ml.svg
        :target: https://travis-ci.com/Ye-Buehler/gdb_ml

.. image:: https://readthedocs.org/projects/gdb-ml/badge/?version=latest
        :target: https://gdb-ml.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




GDB-ML contains all the utils for a GDB machine learning based project.


* Free software: MIT license
* Documentation: https://gdb-ml.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
